*[ACES]: Academy Color Encoding System
*[CAT]: chromatic adaptation transform
*[CATs]: chromatic adaptation transform
*[CCT]: correlated color temperature
*[CMFs]: color matching functions
*[CVD]: color vision deficiency
*[CVDs]: color vision deficiency
*[HDR]: High Dynamic Range
*[HPE]: Hunt-Pointer-Estevez
*[JND]: just noticeable difference
*[LDR]: Low Dynamic Range
*[MINDE]: minimum delta E
*[NaN]: not a number
*[SDR]: Standard Dynamic Range
*[SVG]: Scalable Vector Graphics
*[UCS]: Uniform Chromaticity Space
*[WCAG]: Web Content Accessibility Guidelines
